==> haskell-first-class-families-0.8.0.0-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-first-class-families.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 first-class-families
version:              0.8.0.0
visibility:           public
id:                   first-class-families-0.8.0.0-ABTbuPKSaSRGu0uFezx2sB
key:                  first-class-families-0.8.0.0-ABTbuPKSaSRGu0uFezx2sB
license:              MIT
copyright:            2018 Li-yao Xia
maintainer:           lysxia@gmail.com
author:               Li-yao Xia
homepage:             https://github.com/Lysxia/first-class-families#readme
synopsis:             First class type families
description:
    First class type families,
    eval-style defunctionalization

    See "Fcf".

category:             Other
abi:                  d070bfea64de5d6c9c488aa17a8b8f5e
exposed:              True
exposed-modules:
    Fcf Fcf.Class.Bifunctor Fcf.Class.Foldable Fcf.Class.Functor
    Fcf.Class.Monoid Fcf.Class.Monoid.Types Fcf.Class.Ord Fcf.Classes
    Fcf.Combinators Fcf.Core Fcf.Data.Bool Fcf.Data.Common
    Fcf.Data.Function Fcf.Data.List Fcf.Data.Nat Fcf.Data.Symbol
    Fcf.Utils

import-dirs:          /usr/lib/ghc-8.10.2/site-local/first-class-families-0.8.0.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/first-class-families-0.8.0.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.2/first-class-families-0.8.0.0

hs-libraries:         HSfirst-class-families-0.8.0.0-ABTbuPKSaSRGu0uFezx2sB
depends:              base-4.14.1.0
haddock-interfaces:
    /usr/share/doc/haskell-first-class-families/html/first-class-families.haddock

haddock-html:         /usr/share/doc/haskell-first-class-families/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-first-class-families-0.8.0.0-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-first-class-families.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 first-class-families
version:              0.8.0.0
visibility:           public
id:                   first-class-families-0.8.0.0-5vqmC8XDZGm5STPWNMGd26
key:                  first-class-families-0.8.0.0-5vqmC8XDZGm5STPWNMGd26
license:              MIT
copyright:            2018 Li-yao Xia
maintainer:           lysxia@gmail.com
author:               Li-yao Xia
homepage:             https://github.com/Lysxia/first-class-families#readme
synopsis:             First class type families
description:
    First class type families,
    eval-style defunctionalization

    See "Fcf".

category:             Other
abi:                  e2cf63e6bd6daeca40d39e5f1ebbd0dc
exposed:              True
exposed-modules:
    Fcf Fcf.Class.Bifunctor Fcf.Class.Foldable Fcf.Class.Functor
    Fcf.Class.Monoid Fcf.Class.Monoid.Types Fcf.Class.Ord Fcf.Classes
    Fcf.Combinators Fcf.Core Fcf.Data.Bool Fcf.Data.Common
    Fcf.Data.Function Fcf.Data.List Fcf.Data.Nat Fcf.Data.Symbol
    Fcf.Utils

import-dirs:          /usr/lib/ghc-8.10.2/site-local/first-class-families-0.8.0.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/first-class-families-0.8.0.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.2/first-class-families-0.8.0.0

hs-libraries:         HSfirst-class-families-0.8.0.0-5vqmC8XDZGm5STPWNMGd26
depends:              base-4.14.1.0
haddock-interfaces:
    /usr/share/doc/haskell-first-class-families/html/first-class-families.haddock

haddock-html:         /usr/share/doc/haskell-first-class-families/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
